@@ -1,5 +1,5 @@
 from typing import List
-
+from aicmder.commands.utils import help_str
 import aicmder as cmder
 from aicmder.commands import register
 from aicmder.commands.utils import _command_prefix as cmd
@@ -29,3 +29,10 @@ class PbCommand:
         onnx_model = onnx.load(args.onnx)
         tf_rep = prepare(onnx_model)
         tf_rep.export_graph(os.path.join(save_dir, 'saved_model')) 
+        
+    @staticmethod
+    def help():
+        str = "pb example\n"
+        str += help_str("aicmder pb -o output/export.onnx")
+        str += help_str("-o onnx model filepath")
+        return str
