@@ -8,6 +8,7 @@ import os
 from shutil import copyfile
 from pprint import pprint
 import json
+import time
 # from multiprocessing import set_start_method
 # try:
 #      set_start_method('spawn')
@@ -113,6 +114,7 @@ class ServeCommand:
             python_path = 'python'
         for idx, device_id in enumerate(device_map):
             subprocess.Popen([python_path, self.work_file, json.dumps(config), str(device_id)])
+            time.sleep(3)
             
             # worker = cmder.Worker(config, device_id=device_id)
             # workers.append(worker)
