@@ -164,6 +164,11 @@ class Prediction:
             json_str = req.context.doc
             # print('---', json_str)
             # logging.debug(req, json_str)
+            if "module" in req.params:
+                module_name = req.params["module"]
+                json_str = module_name + '\n' + json_str
+            else:
+                json_str = '\n' + json_str
             result = self.concurrent.send_request(json_str.encode())
             
             if type(result) == bytes:
@@ -173,7 +178,7 @@ class Prediction:
                 result = result.decode('utf-8')
        
             # print(doc, type(doc), doc['test'])
-        except AttributeError as e:
+        except Exception as e:
             print(e)
             raise falcon.HTTPBadRequest(
                 title='Missing thing',
