@@ -9,6 +9,12 @@ import zmq
 import datetime, json, sys, os
 from termcolor import colored
 from aicmder.service import WORKER_PORT
+import signal
+
+
+def handler(signum, frame):
+    raise Exception('Action took too much time')
+
 
 def worker_socket(context, poller):
     """Helper function that returns a new configured socket
@@ -26,6 +32,9 @@ ModuleMethod = cmder.ModuleDefine.ModuleMethod.str()
 ModuleInitArgs = cmder.ModuleDefine.ModuleInitArgs.str()
 ModuleParams = cmder.ModuleDefine.ModuleParams.str()
 DeviceId = cmder.ModuleDefine.DeviceId.str()
+REQUEST_TIMEOUT = 4   # timeout 4 seconds
+
+
 class Worker:
     
     
@@ -41,7 +50,7 @@ class Worker:
         assert len(self.module_infos) > 0
         self.serving_methods = {}
         self.logger = logger
-
+        self.module_name = None
         for module_name, module_info in self.module_infos.items():
             self.logger.info(module_name, module_info)
             
@@ -54,7 +63,8 @@ class Worker:
             serving_method = getattr(module, method_name)
             # serving_args = module_info.get(ModuleParams, {})
             self.serving_methods[module_name] = {ModuleName: module_info[ModuleName], ModuleMethod: serving_method}
-            self.module_name = module_name
+            if self.module_name is None:
+                self.module_name = module_name
         # print(self.serving_methods)
         # self.is_ready = multiprocessing.Event()
         
@@ -85,14 +95,30 @@ class Worker:
                     module = self.serving_methods[self.module_name]
                     serving_args = frames[len(frames) - 1].decode()
                     try:
+                        req_module_name = serving_args.partition('\n')[0]
+                        if len(req_module_name) > 0:
+                            if req_module_name in self.serving_methods:
+                                 module = self.serving_methods[req_module_name]
+                        # else:
+                        #     print("no module name")
+                        serving_args = serving_args.split("\n", 1)[1]
                         serving_args_dict = json.loads(serving_args)
                     except Exception as e:
                         # just in case if not json
                         serving_args_dict = serving_args
-                    if type(serving_args_dict) is dict:
-                        frames[len(frames) - 1] = module[ModuleMethod](**serving_args_dict).encode()
-                    else:
-                        frames[len(frames) - 1] = module[ModuleMethod](serving_args_dict).encode()
+
+                    signal.signal(signal.SIGALRM, handler)
+                    signal.alarm(REQUEST_TIMEOUT) #Set the parameter to the amount of seconds you want to wait
+                    try:
+                        if type(serving_args_dict) is dict:
+                            frames[len(frames) - 1] = module[ModuleMethod](**serving_args_dict).encode()
+                        else:
+                            frames[len(frames) - 1] = module[ModuleMethod](serving_args_dict).encode()
+                    except Exception as e:
+                        self.logger.info(e)
+                        frames[len(frames) - 1] = '{"code":-1}'.encode()
+                    signal.alarm(0) #Disables the alarm 
+
                     self.logger.debug("I: Normal reply")
                     worker.send_multipart(frames)
                     liveness = HEARTBEAT_LIVENESS
