@@ -85,11 +85,11 @@ def argmax(lst):
 def check_object_in_fence(resp_d, fence_list, calculate_usage=False, gap_w=25, gap_h=35, model_name=''):
 
     new_d = []
-    deli_compensation = 22
+    deli_compensation = 5
     if calculate_usage:
         resp_d["fence_usage"] = defaultdict(int)
-        fence_usage_by_width = defaultdict(int)
-        fence_obj_height = defaultdict(list)
+        # fence_usage_by_width = defaultdict(int)
+        # fence_obj_height = defaultdict(list)
         fence_obj_type = defaultdict(str)
     for j, obj in enumerate(resp_d["data"]):
         start_x, end_x, end_y, start_y = obj["start_x"], obj["end_x"], obj["end_y"], obj["start_y"]
@@ -103,30 +103,33 @@ def check_object_in_fence(resp_d, fence_list, calculate_usage=False, gap_w=25, g
         obj_rect = RotatedRect()
         obj_rect.set_param(center_x, center_y, width, height, 0)
         for i, fence in enumerate(fence_list):
-            if fence.pointPolygonTest((center_x, center_y)) == 1:
+            if calculate_usage:
+                    fence_obj_type[i] = obj["label"]
+                    obj_rect_gap = RotatedRect()
+                    if "Deli" in obj["label"]:
+                        obj_rect_gap.set_param(center_x, center_y, width + deli_compensation, height + deli_compensation, 0)
+                        
+                        # resp_d["fence_usage"][i] += (width) * (height)
+                        # fence_usage_by_width[i] += (width + deli_compensation)
+                    elif "CutCake" in obj["label"]:
+                        obj_rect_gap.set_param(center_x, center_y, width, height, 0)
+                    elif "Cake" in obj["label"] and "Cake" == model_name:
+                        obj_rect_gap.set_param(center_x, center_y, width + 30, height + 10, 0)
+                    else:
+                        obj_rect_gap.set_param(center_x, center_y, width + gap_w, height + gap_h, 0)
+                    
+                    resp_d["fence_usage"][i] += fence.fence_rect.occlusion_rate(obj_rect_gap)
+
+                        # resp_d["fence_usage"][i] += (width + gap_w) * (height + gap_h)
+                        # fence_usage_by_width[i] += (width + gap_w)
+                    # fence_obj_height[i].append(height)
+            if fence.pointPolygonTest((center_x, center_y)) == 1 and not hasSelect:
                 # if i == 4:
                 #     print(width, height, width * height, obj["label"])
                 obj["fence"] = i
                 new_d.append(obj)
-                if calculate_usage:
-                    fence_obj_type[i] = obj["label"]
-                    if "Deli" in obj["label"]:
-                        obj_rect_gap = RotatedRect()
-                        obj_rect_gap.set_param(center_x, center_y, width + deli_compensation, height + deli_compensation, 0)
-                        resp_d["fence_usage"][i] += fence.fence_rect.occlusion_rate(obj_rect_gap)
-
-                        # resp_d["fence_usage"][i] += (width) * (height)
-                        fence_usage_by_width[i] += (width + deli_compensation)
-                    else:
-                        obj_rect_gap = RotatedRect()
-                        obj_rect_gap.set_param(center_x, center_y, width + gap_w, height + gap_h, 0)
-                        resp_d["fence_usage"][i] += fence.fence_rect.occlusion_rate(obj_rect_gap)
-
-                        # resp_d["fence_usage"][i] += (width + gap_w) * (height + gap_h)
-                        fence_usage_by_width[i] += (width + gap_w)
-                    fence_obj_height[i].append(height)
                 hasSelect = True
-                break
+
             iou_area = obj_rect.occlusion_rate(fence.fence_rect)
             iou_list.append(iou_area)
         if not hasSelect and "Coin" not in obj["label"]:
@@ -134,39 +137,41 @@ def check_object_in_fence(resp_d, fence_list, calculate_usage=False, gap_w=25, g
             # print(j, width, height, width * height, obj["label"], iou_list, fence_index, obj_rect.get_contour().area, fence_list[fence_index].area())
             obj["fence"] = fence_index
             new_d.append(obj)
-            if calculate_usage:
-                if "Deli" in obj["label"]:
-                    obj_rect_gap = RotatedRect()
-                    obj_rect_gap.set_param(center_x, center_y, width + deli_compensation, height + deli_compensation, 0)
-                    resp_d["fence_usage"][fence_index] += fence.fence_rect.occlusion_rate(obj_rect_gap)
-                    fence_usage_by_width[fence_index] += (width + deli_compensation)
-                else:
-                    obj_rect_gap = RotatedRect()
-                    obj_rect_gap.set_param(center_x, center_y, width + gap_w, height + gap_h, 0)
-                    resp_d["fence_usage"][fence_index] += fence_list[fence_index].fence_rect.occlusion_rate(obj_rect_gap)
-                    # resp_d["fence_usage"][fence_index] += (width + gap_w) * (height + gap_h)
-                    fence_usage_by_width[fence_index] += (width + gap_w)
 
-                fence_obj_height[fence_index].append(height)
+            # if calculate_usage:
+            #     if "Deli" in obj["label"]:
+            #         obj_rect_gap = RotatedRect()
+            #         obj_rect_gap.set_param(center_x, center_y, width + deli_compensation, height + deli_compensation, 0)
+            #         resp_d["fence_usage"][fence_index] += fence.fence_rect.occlusion_rate(obj_rect_gap)
+            #         fence_usage_by_width[fence_index] += (width + deli_compensation)
+            #     else:
+            #         obj_rect_gap = RotatedRect()
+            #         obj_rect_gap.set_param(center_x, center_y, width + gap_w, height + gap_h, 0)
+            #         resp_d["fence_usage"][fence_index] += fence_list[fence_index].fence_rect.occlusion_rate(obj_rect_gap)
+            #         # resp_d["fence_usage"][fence_index] += (width + gap_w) * (height + gap_h)
+            #         fence_usage_by_width[fence_index] += (width + gap_w)
+
+                # fence_obj_height[fence_index].append(height)
     # print("---", len(new_d), len(resp_d["data"]))
     resp_d["data"] = new_d
     if calculate_usage:
         for fence_idx in resp_d["fence_usage"]:
-            current_fence = fence_list[fence_idx]
+            # current_fence = fence_list[fence_idx]
+
             # usage = resp_d["fence_usage"][fence_idx] / current_fence.area()
             usage = resp_d["fence_usage"][fence_idx]
 
-            if "Cake" in fence_obj_type[fence_idx]:
-                obj_heights = fence_obj_height[fence_idx]
-                obj_heights.sort()
-                if len(obj_heights) > 0:
-                    min_height = obj_heights[0]
-                    min_height_scale = min_height * 1.85
-                    # if fence_idx == 4:
-                        # print(min_height, min_height_scale, current_fence.height(), current_fence.width(), usage)
+            # if "Cake" in fence_obj_type[fence_idx]:
+            #     obj_heights = fence_obj_height[fence_idx]
+            #     obj_heights.sort()
+            #     if len(obj_heights) > 0:
+            #         min_height = obj_heights[0]
+            #         min_height_scale = min_height * 1.85
+            #         # if fence_idx == 4:
+            #             # print(min_height, min_height_scale, current_fence.height(), current_fence.width(), usage)
 
-                    if min_height_scale > current_fence.height():
-                        usage = fence_usage_by_width[fence_idx] / current_fence.width()
+            #         if min_height_scale > current_fence.height():
+            #             usage = fence_usage_by_width[fence_idx] / current_fence.width()
 
             if usage > 1:
                 usage = 1
